calculate_Rt-method: Methods for Function 'calculate_Rt'

calculate_Rt-methodsR Documentation

Methods for Function calculate_Rt

Description

Methods for function calculate_Rt

Methods

signature( object = "infpan", GP = 4, correction = FALSE, col_name = NULL, verbose = FALSE)

Calculates the effective reproduction number R_t for all time points for each region in the infections panel data. Set the generation period by the parameter GP (default: 4). If correction is TRUE, values equal to zero are increased by one. Set overwrite to TRUE, if an existing column should be overwritten. The method uses the built-in function R_t().

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.