calculate_cum-method: Methods for Function 'calculate_cum'

calculate_cum-methodsR Documentation

Methods for Function calculate_cum

Description

Methods for function calculate_cum

Methods

signature( object = "infpan", col_name = NULL, verbose = FALSE)

Calculates the cumulative values of the infections panel data for all time points for each region. If col_name is NULL, the column is defined as "<Column name of cases>_cum" The method uses the function cumsum from the base package (see the corresponding documentation).

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.