calculate_incidence-method: Methods for Function 'calculate_incidence'

calculate_incidence-methodsR Documentation

Methods for Function calculate_incidence

Description

Methods for function calculate_incidence

Methods

signature( object, use_column = "Cases", col_name = NULL, pop_factor = 100000, overwrite = FALSE, verbose = FALSE)

Calculates the incidence of the infections panel data for all time points for each region. Use use_column to specify which column should be used for the calculation of incidence. The following values are permitted: "Cases" (default, incremental cases), "Cum. cases" (cumulative cases), "Roll. mean" (rolling mean of cases), or "Roll. sum" (rolling sum of cases). If the specified column does not exist in the infections panel data of the infpan object, the function raises an error. If in the infpan object, no "Population" column is defined, incidence calculation is not possible. If col_name is NULL, the column is defined as "<Column name of cases>_inc". Set overwrite to TRUE, if an existing column should be overwritten.

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.