calculate_rollmean-method: Methods for Function 'calculate_rollmean'

calculate_rollmean-methodsR Documentation

Methods for Function calculate_rollmean

Description

Methods for function calculate_rollmean

Methods

signature( object = "infpan", k = 7, align = "center", fill = NA, col_name = NULL, verbose = FALSE)

Calculates the rolling mean of the infections panel data for all time points for each region. Set the rolling window by the parameter k (default: 7). Set the fill value for the observations left/within/right to the data range with parameter fill (default: NA). Parameter align defines whether the index of the result should be left- or right-aligned or centered (default). If col_name is NULL, the column is defined as "<Column name of cases>_rm". The method uses the function rollmean from the zoo package (see the corresponding documentation).

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.