countries-class: Class '"countries"'

countries-classR Documentation

Class "countries"

Description

The class countries contains the results of a two-country comparison analysis using the Swash-Backwash Model, including two sbm_ci objects for each country. Use summary(countries) and plot(countries) for results summary and plotting, respectively.

Objects from the Class

Objects can be created by the function compare_countries(sbm1, sbm2).

Slots

sbm_ci1:

Object of class "sbm_ci" Results of "confint(sbm1)" for country 1

sbm_ci2:

Object of class "sbm_ci" Results of "confint(sbm1)" for country 2

D:

Object of class "numeric" Results: Difference D between the samples with respect to the chosen indicator

D_ci:

Object of class "numeric" Results: \alpha confidence intervals of D

config:

Object of class "list" Configuration details for bootstrap sampling

country_names:

Object of class "character" User-stated country names

indicator:

Object of class "character" User-stated indicator to be tested

Methods

plot

signature(x = "countries"): Plots the results of a two-country comparison with the Swash-Backwash Model

show

signature(object = "countries"): Prints an countries object; use summary(sbm_ci) for results

print

signature(object = "countries"): Prints an countries object; use summary(sbm_ci) for results

summary

signature(object = "countries"): Prints a summary of a countries object (results of the two-country comparison)

Author(s)

Thomas Wieland

Examples

showClass("countries")

swash documentation built on May 24, 2026, 9:06 a.m.