growth-methods: Methods for Function 'growth'

growth-methodsR Documentation

Methods for Function growth

Description

Methods for function growth

Methods

signature(object = "infpan", S_iterations = 10, S_start_est_method = "bisect", seq_by = 10, nls = TRUE, add_constant = 1, verbose = FALSE)

Estimation of N logistic growth models for N regions. Both OLS and NLS estimation are estimated by default (set nls = FALSE to skip NLS estimation). Parameters S_iterations, S_start_est_method, and seq_by are used to control the saturation value estimation (see logistic_growth).

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.