growth_hawkes: Hawkes Processs models for Regional Infections

growth_hawkesR Documentation

Hawkes Processs models for Regional Infections

Description

Estimates N Hawkes process models for N regions.

Usage

growth_hawkes(
  object, 
  optim_method = "L-BFGS-B",
  verbose = FALSE
  )

Arguments

object

object of class infpan

optim_method

character value for the optimization method. Passed to argument method in stats function optim()

verbose

bool argument which indicates whether progress messages are displayed

Details

The function estimates Hawkes process models for regional infections based on an infpan object. See hawkes_growth for further details of the estimation.

Value

object of class growthmodels-class

Author(s)

Thomas Wieland

References

Rizoiu MA, Mishra S, Kong Q, Carman M, Xie L. (2018) SIR-Hawkes: Linking Epidemic Models and Hawkes Processes to Model Diffusions in Finite Populations. In: Proceedings of the 2018 World Wide Web Conference. WWW’18. Republic and Canton of Geneva, CHE: International World Wide Web Conferences Steering Committee, p. 419–428. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1145/3178876.3186108")}

Examples

data(COVID19Cases_geoRegion)
# Get SWISS COVID19 cases at NUTS 3 level

COVID19Cases_geoRegion <- 
  COVID19Cases_geoRegion[!COVID19Cases_geoRegion$geoRegion %in% c("CH", "CHFL"),]
# Exclude CH = Switzerland total and CHFL = Switzerland and Liechtenstein total

COVID19Cases_geoRegion <- 
  COVID19Cases_geoRegion[COVID19Cases_geoRegion$datum <= "2020-05-31",]
# Extract first COVID-19 wave

infpan_CH <- load_infections_paneldata(
    data = COVID19Cases_geoRegion,
    col_cases = "entries",
    col_date = "datum",
    col_region = "geoRegion",
    other_cols = c("Population" = "pop"), 
    verbose = TRUE
  )
# Import as infections panel data set (class infpan)

CH_covidwave1_Hawkes <- 
  growth_hawkes(infpan_CH)
summary(CH_covidwave1_Hawkes)
# Hawkes process models for infpan object infpan_CH 

swash documentation built on April 7, 2026, 1:06 a.m.