growth_initial-methods: Methods for Function 'growth_initial'

growth_initial-methodsR Documentation

Methods for Function growth_initial

Description

Methods for function growth_initial

Methods

signature(object = "infpan", time_units = 10, GI = 4, nls = TRUE, nls_start = list(a = 1, b = 0.1), add_constant = 1, verbose = FALSE)

Estimation of N exponential growth models for the initial phase of an epidemic spread for N regions. Set argument GI for the calculation of the basic reproduction number, and control OLS/NLS estimation with arguments nls, nls_start, and add_constant (see exponential_growth).

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.