hawkes_growth: Hawkes Process Model for Epidemic Data

hawkes_growthR Documentation

Hawkes Process Model for Epidemic Data

Description

Estimation of Hawkes Process models from incremental infections data

Usage

hawkes_growth(
  y,
  optim_method = "L-BFGS-B",
  verbose = FALSE
  )

Arguments

y

numeric vector with incremental infections data over time (e.g., daily infections)

optim_method

character specifying the optimization algorithm, passed to stats::optim

verbose

bool argument which indicates whether progress messages are displayed

Details

This function allows the estimation of a Hawkes Process model, with the time decay being expressed as exponential function, which results in three estimated parameters: \mu (background rate), \alpha (excitation parameter), and \beta (decay). The user must specify the dependent variable (incremental infections). The estimation is performed using nonlinear estimation via stats::optim. See the corresponding documentation for available optimization methods (default: "L-BFGS-B").

Value

object of class hawkes-class

Author(s)

Thomas Wieland

References

Rizoiu MA, Mishra S, Kong Q, Carman M, Xie L. (2018) SIR-Hawkes: Linking Epidemic Models and Hawkes Processes to Model Diffusions in Finite Populations. In: Proceedings of the 2018 World Wide Web Conference. WWW’18. Republic and Canton of Geneva, CHE: International World Wide Web Conferences Steering Committee, p. 419–428. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1145/3178876.3186108")}

See Also

logistic_growth, exponential_growth, breaks_growth

Examples

data(Infections)
# Confirmed SARS-CoV-2 cases in Germany

hawkes_BS <- hawkes_growth(
  y = Infections$infections_daily
)
# Hawkes Process model

summary(hawkes_BS)
# Summary of Hawkes model estimates

plot(hawkes_BS)
# Plot of Hawkes Process model

swash documentation built on May 24, 2026, 9:06 a.m.