infpan-class: Class '"infpan"'

infpan-classR Documentation

Class "infpan"

Description

The class "infpan" contains infections panel data for N regions and T time points as well as additional information. Use summary(infpan) and plot(infpan) for results summary and plotting, respectively.

Objects from the Class

Objects can be created by importing infections panel data using the function load_infections_paneldata.

Slots

input_data:

Object of class "data.frame" Model result: Input infections panel data

data_statistics:

Object of class "numeric" Data statistics (N regions, T time points, test whether data is balanced, etc.)

index_col_names:

Object of class "character" Column names of regions and time points

cases_col_name:

Object of class "character" Column name of incremental cases

other_cols:

Object of class "character" Names of other relevant columns derived from incremental case data, e.g. effective reproduction number R_t

time_format:

Object of class "character" Format of time points in time column

time_unit:

Object of class "character" Time unit, default: "days"

timestamp:

Object of class "list" Time stamps of any update of the instance

Methods

plot

signature(x = "infpan"): Plots case data by region for N regions and T time points

calculate_Rt

signature(x = "infpan"): Calculates the effective reproduction number R_t from infpan objects. Returns updated infpan instance.

calculate_cum

signature(x = "infpan"): Calculates cumulative cases from infpan objects. Returns updated infpan instance.

calculate_rollmean

signature(x = "infpan"): Calculates rolling means of cases from infpan objects. Returns updated infpan instance.

calculate_incidence

signature(x = "infpan"): Calculates incidences of cases from infpan objects. Returns updated infpan instance.

print

signature(x = "infpan"): Prints an infpan object; use summary(infpan) for results

show

signature(object = "infpan"): Shows an infpan object; use summary(infpan) for results

summary

signature(object = "infpan"): Prints a summary of infpan objects

swash

signature(object = "infpan"): Performs a Swash-Backwash Model analysis from infpan objects. Returns sbm instance.

growth

signature(object = "infpan"): Estimates logistic growth models from infpan objects. Returns growthmodels instance.

growth_initial

signature(object = "infpan"): Estimates exponential growth models from infpan objects for a given time period. Returns growthmodels instance.

growth_hawkes

signature(object = "infpan"): Estimates Hawkes process models from infpan objects. Returns growthmodels instance.

Author(s)

Thomas Wieland

References

Wieland T (2020) Flatten the Curve! Modeling SARS-CoV-2/COVID-19 Growth in Germany at the County Level. REGION 7(2), 43–83. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.18335/region.v7i2.324")}

Wieland T (2025) Assessing the effectiveness of non-pharmaceutical interventions in the SARS-CoV-2 pandemic: results of a natural experiment regarding Baden-Württemberg (Germany) and Switzerland in the second infection wave. Journal of Public Health 33(11), 2497-2511. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1007/s10389-024-02218-x")}

Examples

showClass("infpan")

swash documentation built on April 7, 2026, 1:06 a.m.