summary-methods: Methods for Function 'summary'

summary-methodsR Documentation

Methods for Function summary

Description

Methods for function summary

Methods

signature(object = "sbm")

Prints a summary of sbm objects (results of the Swash-Backwash Model)

signature(object = "sbm_ci")

Prints a summary of sbm_ci objects (bootstrap confidence intervals for Swash-Backwash Model estimates)

signature(object = "countries")

Prints a summary of a countries object built with the function compare_countries

signature(object = "loggrowth")

Prints a summary of a loggrowth object built with the function logistic_growth

signature(object = "expgrowth")

Prints a summary of a expgrowth object built with the function exponential_growth

signature(object = "hawkes")

Prints a summary of a hawkes object built with the function hawkes_growth

signature(object = "breaksgrowth")

Prints a summary of a breaksgrowth object built with the function breaks_growth


swash documentation built on April 7, 2026, 1:06 a.m.