swash-method: Methods for Function 'swash'

swash-methodsR Documentation

Methods for Function swash

Description

Methods for function swash

Methods

signature( object = "infpan", verbose = FALSE)

Performs the analysis of the input panel data with N regions and T time points using the Swash-Backwash Model based on an infpan object. The output is an object of class "sbm". The results can be viewed using summary(sbm). See swash_backwash for further details of the model analysis.

Author(s)

Thomas Wieland


swash documentation built on April 7, 2026, 1:06 a.m.