| calculate_Rt-methods | R Documentation |
calculate_RtMethods for function calculate_Rt
signature(
object = "infpan",
GP = 4,
correction = FALSE,
col_name = NULL,
verbose = FALSE)Calculates the effective reproduction number R_t for all time points for each region in the infections panel data.
Set the generation period by the parameter GP (default: 4).
If correction is TRUE, values equal to zero are increased by one.
Set overwrite to TRUE, if an existing column should be overwritten.
The method uses the built-in function R_t().
Thomas Wieland
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.