| calculate_cum-methods | R Documentation |
calculate_cumMethods for function calculate_cum
signature(
object = "infpan",
col_name = NULL,
verbose = FALSE)Calculates the cumulative values of the infections panel data for all time points for each region.
If col_name is NULL, the column is defined as "<Column name of cases>_cum"
The method uses the function cumsum from the base package (see the corresponding documentation).
Thomas Wieland
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.