| countries-class | R Documentation |
"countries"The class countries contains the results of a two-country comparison analysis using the Swash-Backwash Model,
including two sbm_ci objects for each country. Use summary(countries) and plot(countries)
for results summary and plotting, respectively.
Objects can be created by the function compare_countries(sbm1, sbm2).
sbm_ci1:Object of class "sbm_ci" Results of "confint(sbm1)" for country 1
sbm_ci2:Object of class "sbm_ci" Results of "confint(sbm1)" for country 2
D:Object of class "numeric" Results: Difference D between the samples with respect to the chosen indicator
D_ci:Object of class "numeric" Results: \alpha confidence intervals of D
config:Object of class "list" Configuration details for bootstrap sampling
country_names:Object of class "character" User-stated country names
indicator:Object of class "character" User-stated indicator to be tested
signature(x = "countries"): Plots the results of a two-country comparison with the Swash-Backwash Model
signature(object = "countries"): Prints an countries object; use summary(sbm_ci) for results
signature(object = "countries"): Prints an countries object; use summary(sbm_ci) for results
signature(object = "countries"): Prints a summary of a countries object (results of the two-country comparison)
Thomas Wieland
showClass("countries")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.