| growthmodels-class | R Documentation |
"growthmodels"The class "growthmodels" contains the results of growth model analyses and the related input data as well as additional information.
The swash package includes the following model analyses under the heading "growth models": Exponential growth models,
logistic growth models, Hansen Process models, and time series models with breakpoints.
Use summary(growthmodels) for results summary.
See the corresponding functions for details: exponential_growth, logistic_growth, hawkes_growth, breaks_growth.
Objects can be created by the functions exponential_growth, logistic_growth, breaks_growth, or hawkes_growth.
results:Object of class "data.frame" Model results as a table with coefficents, fit metrics, etc.
growth_models:Object of class "list" containing all models
model_type:Object of class "character" describing the type of model
results_cols:Object of class "character" Vector with column names containing results
results_cols_names:Object of class "character" Vector with descriptions of the column names
data_statistics:Object of class "numeric" Diagnostics of input data
time_format:Object of class "character" Format of time points in time column
timestamp:Object of class "list" Time stamps of any update of the instance
signature(x = "growthmodels"): Prints an growthmodels object; use summary(growthmodels) for results
signature(object = "growthmodels"): Prints an growthmodels object; use summary(growthmodels) for results
signature(object = "growthmodels"): Prints a summary of growthmodels objects (model results)
Thomas Wieland
Bai J, Perron P (2003) Computation and analysis of multiple structural change models. Journal of Applied Econometrics 18(1), 1-22. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1002/jae.659")}
Bonifazi G et al. (2021) A simplified estimate of the effective reproduction number Rt using its relation with the doubling time and application to Italian COVID-19 data. The European Physical Journal Plus 136, 386. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1140/epjp/s13360-021-01339-6")}
Chowell G, Simonsen L, Viboud C, Yang K (2014) Is West Africa Approaching a Catastrophic Phase or is the 2014 Ebola Epidemic Slowing Down? Different Models Yield Different Answers for Liberia. PLoS currents 6. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://dx.doi.org/10.1371/currents.outbreaks.b4690859d91684da963dc40e00f3da81")}
Chowell G, Viboud C, Hyman JM, Simonsen L (2015) The Western Africa ebola virus disease epidemic exhibits both global exponential and local polynomial growth rates. PLOS Currents Outbreaks, ecurrents.outbreaks.8b55f4bad99ac5c5db3663e916803261. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1371/currents.outbreaks.8b55f4bad99ac5c5db3663e916803261")}
Pell B, Kuang Y, Viboud C, Chowell G (2018) Using phenomenological models for forecasting the 2015 ebola challenge. Epidemics 22, 62–70. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1016/j.epidem.2016.11.002")}
Rizoiu MA, Mishra S, Kong Q, Carman M, Xie L. (2018) SIR-Hawkes: Linking Epidemic Models and Hawkes Processes to Model Diffusions in Finite Populations. In: Proceedings of the 2018 World Wide Web Conference. WWW’18. Republic and Canton of Geneva, CHE: International World Wide Web Conferences Steering Committee, p. 419–428. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1145/3178876.3186108")}
Wieland T (2020) A phenomenological approach to assessing the effectiveness of COVID-19 related nonpharmaceutical interventions in Germany. Safety Science 131, 104924. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1016/j.ssci.2020.104924")}
Wieland T (2020) Flatten the Curve! Modeling SARS-CoV-2/COVID-19 Growth in Germany at the County Level. REGION 7(2), 43–83. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.18335/region.v7i2.324")}
Zeileis C, Kleiber W, Krämer K, Hornik, K (2003) Testing and dating of structural changes in practice. Computational Statistics & Data Analysis 44(1-2), 109-123. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1016/S0167-9473(03)00030-6")}
showClass("growthmodels")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.