| hawkes-class | R Documentation |
"hawkes"The class "hawkes" contains the results of the hawkes_growth() function.
Use summary(hawkes) for results summary.
Objects can be created by the function hawkes_growth.
t:Object of class numeric Input time points data
y:Object of class numeric Input infections data
mu:Object of class numeric Estimated \mu parameter
alpha:Object of class numeric Estimated \alpha parameter
beta:Object of class numeric Estimated \beta parameter
br:Object of class numeric Estimated breaking ratio (\alpha/\beta)
y_pred:Object of class numeric Predicted values of y
fit_metrics:Object of class list Fit metrics for model, output from built-in function fit_metrics
config:Object of class list Model fit configurations
signature(object = "hawkes"): Prints a summary of hawkes objects
signature(x = "hawkes"): Prints an hawkes object; use summary(hawkes) for results
signature(x = "hawkes"): Plots the results of the Hawkes model (observed, predicted)
Thomas Wieland
Rizoiu MA, Mishra S, Kong Q, Carman M, Xie L. (2018) SIR-Hawkes: Linking Epidemic Models and Hawkes Processes to Model Diffusions in Finite Populations. In: Proceedings of the 2018 World Wide Web Conference. WWW’18. Republic and Canton of Geneva, CHE: International World Wide Web Conferences Steering Committee, p. 419–428. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1145/3178876.3186108")}
showClass("hawkes")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.