| hawkes_growth | R Documentation |
Estimation of Hawkes Process models from incremental infections data
hawkes_growth(
y,
optim_method = "L-BFGS-B",
verbose = FALSE
)
y |
|
optim_method |
|
verbose |
|
This function allows the estimation of a Hawkes Process model, with the time decay being expressed as exponential function,
which results in three estimated parameters: \mu (background rate), \alpha (excitation parameter), and \beta (decay).
The user must specify the dependent variable (incremental infections).
The estimation is performed using nonlinear estimation via stats::optim.
See the corresponding documentation for available optimization methods (default: "L-BFGS-B").
object of class hawkes-class
Thomas Wieland
Rizoiu MA, Mishra S, Kong Q, Carman M, Xie L. (2018) SIR-Hawkes: Linking Epidemic Models and Hawkes Processes to Model Diffusions in Finite Populations. In: Proceedings of the 2018 World Wide Web Conference. WWW’18. Republic and Canton of Geneva, CHE: International World Wide Web Conferences Steering Committee, p. 419–428. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1145/3178876.3186108")}
logistic_growth, exponential_growth, breaks_growth
data(Infections)
# Confirmed SARS-CoV-2 cases in Germany
hawkes_BS <- hawkes_growth(
y = Infections$infections_daily
)
# Hawkes Process model
summary(hawkes_BS)
# Summary of Hawkes model estimates
plot(hawkes_BS)
# Plot of Hawkes Process model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.